function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? module.exports = factory() : typeof define === 'function' && define.amd ? define(factory) : (global = global || self, global.foxsdk = factory());
})(this, function () {
  /**
   * @created by anonymous 2019-12-28
   * @updated by
   * @description 工具方法
   */

  /**
   * SDK日志输出类
   */
  var Logger = function () {
    var emptyFn = function () {};

    this.fn = window.console || {
      debug: emptyFn,
      info: emptyFn,
      warn: emptyFn,
      error: emptyFn
    };
    this.fn.debug = this.fn.debug || this.fn.info;
    this.configLevel();
  };

  _extends(Logger.prototype, {
    configLevel: function (options) {
      options = options || {
        info: true,
        debug: true,
        warn: true,
        error: true
      };

      _extends(this, {
        level: options
      });
    },
    debug: function () {
      var ref;
      var args = [],
          len = arguments.length;

      while (len--) args[len] = arguments[len];

      this.level.debug && (ref = this.fn).debug.apply(ref, args);
    },
    info: function () {
      var ref;
      var args = [],
          len = arguments.length;

      while (len--) args[len] = arguments[len];

      this.level.info && (ref = this.fn).info.apply(ref, args);
    },
    warn: function () {
      var ref;
      var args = [],
          len = arguments.length;

      while (len--) args[len] = arguments[len];

      this.level.warn && (ref = this.fn).warn.apply(ref, args);
    },
    error: function () {
      var ref;
      var args = [],
          len = arguments.length;

      while (len--) args[len] = arguments[len];

      this.level.error && (ref = this.fn).error.apply(ref, args);
    }
  });
  /** 实例化logger */


  var logger = new Logger();
  /**
   * 原生返回状态码
   */

  var NATIVE_STATUS_CODE = {
    /**
     * 成功
     */
    OK: '0',

    /**
     * 持续调用
     */
    PROCESS: '1',

    /**
     * 非0|1都表示失败
     * 10004: payload数据解析异常
     */
    FAIL: '10004' // 更多错误码
    // http://192.168.251.162:8090/pages/viewpage.action?pageId=7603575

  };
  /**
   * 每生成一个ID，则自增一次
   */

  var UNIQUE_ID = 0;
  /**
   * 生成唯一的ID
   * @param {*} prefix id前缀，默认uid
   */

  var uuid = function (prefix) {
    if (prefix === void 0) prefix = 'uid';
    return prefix + UNIQUE_ID++ + new Date().getTime();
  };
  /**
   * 对象转成URL参数
   */


  var addUrlParams = function (params) {
    var paramsData = '';
    Object.keys(params).forEach(function (key) {
      paramsData += key + '=' + encodeURIComponent(params[key]) + '&';
    });
    return paramsData.substring(0, paramsData.length - 1);
  };
  /**
   * SDK错误
   * @param {*} status 错误码
   * @param {*} message 错误信息
   */


  var SdkError = function (status, message) {
    this.status = status;
    this.message = message;
    logger.warn('SdkError:', '{"status": "' + this.status + '","message": "' + this.message + '"}');
  };
  /**
   * 输出错误信息
   */


  SdkError.prototype.toString = function () {
    return 'SdkError: {"status": "' + this.status + '","message": "' + this.message + '"}';
  };
  /**
   * 延迟执行任务
   * @param {*} fn 延迟执行方法
   * @param {*} millisecond 延迟时间毫秒
   */


  var delayTask = function (fn, millisecond) {
    var id = setTimeout(function () {
      clearTask(id);
      id = null;
      fn();
    }, millisecond);
    return id;
  };
  /**
   * 清除延迟处理
   * @param {*} id 延迟任务ID
   */


  var clearTask = function (id) {
    id !== undefined && window.clearTimeout(id);
  };
  /**
   * JS继承
   */


  var extendClazz = function (supClazz, subClazz) {
    var proto = Object.create(supClazz.prototype);
    proto.constructor = subClazz;
    subClazz.prototype = proto;
  };
  /**
   * 导出工具方法对象
   */


  var utils = {
    logger: logger,
    NATIVE_STATUS_CODE: NATIVE_STATUS_CODE,
    SdkError: SdkError,
    delayTask: delayTask,
    clearTask: clearTask,
    uuid: uuid,
    addUrlParams: addUrlParams,
    extendClazz: extendClazz
  };
  var logger$1 = utils.logger;
  var SdkError$1 = utils.SdkError;
  var NATIVE_STATUS_CODE$1 = utils.NATIVE_STATUS_CODE;
  var __FOX_COMMAND_URL__ = 'https://__wvjb_queue_message__';
  window.__FOX_CALLBACKS__ = {}; // JS调用native接口时的回调方法，临时存储

  var isIOS = window.__FOX_PLATFORM__ === 'iOS'; // Android 页面load前不能直接注入变量（仅能注入方法对象），故直接使用__FOX_NATIVE_CALL__.call
  // const isAndroid = window.__FOX_PLATFORM__ === 'Android';

  var isAndroid = window.__FOX_NATIVE_CALL__ && typeof window.__FOX_NATIVE_CALL__.call === 'function';
  /**
   * 创建桥接的iframe
   * @returns bridgeiframe
   */

  var createExecIframe = function () {
    var execIframe = document.createElement('iframe');
    execIframe.style.display = 'none'; // 创建iframe并放到body里面去

    var appendToBody = function (iframe) {
      var body = document.body;

      if (body) {
        iframe.parentNode || body.appendChild(iframe);
      } else {
        window.setTimeout(function () {
          appendToBody(iframe);
        }, 100);
      }
    };

    appendToBody(execIframe);
    return execIframe;
  };

  var callAndroid = function (clazz, action, data, callbackid) {
    /* eslint no-undef: 0 */
    if (!window.__FOX_NATIVE_CALL__) {
      throw new SdkError$1('10005', 'The current environment cannot call the bridge layer. Because “window.__FOX_NATIVE_CALL__” does not available on Android.');
    } // JS调用原生方法
    // @param {String} classname 类名
    // @param {String} action 方法名
    // @param {String} data 传递数据
    // @param {String} callbackid 回调方法ID


    window.__FOX_NATIVE_CALL__.call(clazz, action, data, callbackid);
  };

  var callIos = function (clazz, action, data, callbackid) {
    var urlParams = utils.addUrlParams({
      classname: clazz,
      action: action,
      data: data,
      callbackid: callbackid
    });
    var execIframe = createExecIframe();
    execIframe.src = __FOX_COMMAND_URL__ + '?' + urlParams; // 移除DOM中的调用原生桥接

    window.setTimeout(function () {
      execIframe.parentNode && execIframe.parentNode.removeChild(execIframe);
    }, 100);
  };
  /**
   * JS调用原生方法
   * @param {String} clazz 类名
   * @param {String} action 方法名
   * @param {String/Object} data 传递数据
   * @param {Function} callback 回调方法
   * @returns {String} callbackid 回调id
   */


  var call = function (clazz, action, data, callback) {
    var callbackid = utils.uuid('cbid');

    if (data.isGlobel === 0) {
      !window.globalCbId && (window.globalCbId = {});
      window.globalCbId[data.eventName] = callbackid;
    }

    data = typeof data === 'string' ? data : JSON.stringify(data);
    window.__FOX_CALLBACKS__[callbackid] = callback;
    logger$1.debug('X====bridge-call====\n callbackid: ' + callbackid + ',\n clazz: ' + clazz + ',\n action: ' + action + ',\n data: ' + data + '');

    if (!isAndroid && !isIOS) {
      throw new SdkError$1('10005', 'The current environment cannot call the bridge layer.');
    }

    isIOS ? callIos(clazz, action, data, callbackid) : callAndroid(clazz, action, data, callbackid);
    return callbackid;
  };
  /**
   * 移除指定callbackid对应的回调方法，主要是针对于
   * @param {*} callbackid 回调ID
   */


  var removeCb = function (callbackid, callbacks) {
    callbacks = callbacks || window.__FOX_CALLBACKS__;
    callbacks[callbackid] = null;
    delete callbacks[callbackid];
  };
  /**
   * 子线程回调
   * @param {*} callbacks JS调用native接口时的回调方法，临时存储
   * @param {*} callbackid 唯一识别码
   * @param {*} status 错误码：OK: 成功, FAIL: 失败, PROCESS: 持续进行中
   * @param {*} message 错误信息
   * @param {*} payload 回调json数据
   */


  var nextTick = function (callbacks, callbackid, status, message, payload) {
    try {
      payload = JSON.parse(payload);
    } catch (e) {
      logger$1.debug('X====bridge-nextTick==== \n Native return payload data is not in standard JSON format. \n ' + e);
      status = NATIVE_STATUS_CODE$1.FAIL;
      message = 'Native return payload data is not in standard JSON format.';
    }

    var retObj = {
      status: status,
      message: message,
      payload: payload
    };
    var cb = callbacks[callbackid];

    if (status === NATIVE_STATUS_CODE$1.PROCESS) {
      retObj.status = NATIVE_STATUS_CODE$1.OK;
    } else {
      removeCb(callbackid, callbacks);
    }

    logger$1.debug('X====bridge-nextTick====00');
    cb(retObj);
  };
  /**
   * 原生调用JS的回调方法，最终会挂载到: window.__FOX_NATIVE_EVAL__
   * @param {*} callbackid 唯一识别码
   * @param {*} status 错误码：0: 成功, 1: 持续进行中, 其它状态是失败
   * @param {*} message 错误信息
   * @param {*} payload 回调json数据
   */


  var nativeEval = function (callbackid, status, message, payload) {
    logger$1.debug('X====bridge-nativeEval==== \n callbackid: ' + callbackid + ',\n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload + '');
    payload = payload || '{}';

    if (window.__FOX_CALLBACKS__[callbackid]) {
      window.setTimeout(function () {
        nextTick(window.__FOX_CALLBACKS__, callbackid, status, message, payload);
      }, 1);
    }
  };

  var bridge = {
    call: call,
    nativeEval: nativeEval,
    removeCb: removeCb
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors  : chencm
   * @LastEditTime : 2020-01-13 17:21:56
   * @Description: 网络请求
   */

  var http = {
    /**
     * @description 发起网络请求
     * @type {Function}
     * @param {String} data
     * {
     *    url : xxxx,
     *    method : ”POST”,
     *    header : { device_id : ”212121313”},
     *    parameter : {search : ”yuxin”}
     * }
     */
    request: function (data, cb) {
      bridge.call('Request', 'request', data, cb);
    },

    /**
     * @description 取消网络请求
     * @type {Function}
     * @param {String} data
     * {
     *    url : xxxx,
     * }
     */
    doCancel: function (data, cb) {
      bridge.call('Request', 'doCancel', data, cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2020-01-07 15:23:13
   * @LastEditors  : helin3
   * @LastEditTime : 2020-02-04 19:00:37
   * @Description: 文件下载
   */

  var logger$2 = utils.logger;
  var NATIVE_STATUS_CODE$2 = utils.NATIVE_STATUS_CODE;
  /**
   * 下载任务列表
   */

  var __DOWNLOAD_TASK_LIST__ = {};
  /**
   * 下载状态
   */

  var DownloadState = {
    /**
     * 下载任务未开始
     */
    Undefined: -1001,

    /**
     * 所有下载任务
     */
    All: -1,

    /**
     * 下载任务开始调度
     */
    Start: 0,

    /**
     * 下载任务开始请求,发送请求到服务器并等待服务器的响应
     */
    StartRequest: 1,

    /**
     * 下载任务请求已经接收,服务器返回响应，准备传输数据内容
     */
    ReadReceived: 2,

    /**
     * 下载任务接收数据,可多次触发此状态。
     */
    Received: 3,

    /**
     * 下载任务已完成（成功）
     */
    Finished: 4,

    /**
     * 下载任务已暂停
     */
    Pause: 5,

    /**
     * 下载任务发生异常
     */
    Error: 6
  };
  /**
   * 下载任务对象
   */

  var DownloadTask = function (options) {
    /**
     * 下载任务TaskId
     */
    this.identify = utils.uuid('dtask');
    this.options = options || {};
    this.url = this.options.url || '';
    /**
     * 网络请求类型
     * 支持http协议的“GET”、“POST”，默认为“GET”请求。
     */

    this.method = this.options.method || 'get';
    /**
     * POST请求时提交的数据
     * 仅在网络请求类型method设置为"POST"时有效，"GET"请求时忽略此数据。
     */

    this.data = this.options.data || '';
    /**
     * 设置下载请求的HTTP头数据
     */

    this.header = this.options.header || {};
    /**
     * 下载文件保存的路径
     * 保存文件路径仅支持以"_downloads/"、"_doc/"、"_documents/"开头的字符串。
     * 文件路径以文件后缀名结尾（如"_doc/download/a.doc"）表明指定保存文件目录及名称，
     * 以“/”结尾则认为指定保存文件的目录（此时程序自动生成文件名）。
     * 默认保存目录为（"_downloads"），并自动生成文件名称。
     */

    this.filename = this.options.filename || '_downloads/';
    /**
     * 下载任务超时时间（暂不支持）
     * 数值类型，单位为s(秒)，默认值为120s。
     * 超时时间为服务器响应请求的时间（不是下载任务完成的总时间），如果设置为0则表示永远不超时。
     */

    this.timeout = this.options.timeout || 120;
    /**
     * 下载任务的优先级（暂不支持）
     * 数值类型，数值越大优先级越高，默认优先级值为0。
     */

    this.priority = this.options.priority || 0;
    /**
     * 下载任务重试次数（暂不支持）
     * 数值类型，默认为重试3次。
     */

    this.retry = this.options.retry || 3;
    /**
     * 下载任务重试间隔时间（暂不支持）
     * 数值类型，单位为s(秒)，默认值为30s。
     */

    this.retryInterval = this.options.retryInterval || 30;
    this.totalSize = 0;
    this.downloadedSize = 0;
    /**
     * 下载任务当前状态
     */

    this.state = -1001;
    /**
     * 下载任务完成回调
     * @param {DownloadTask} task 下载任务对象
     */

    this.completedCb = options.completedCb || function (task) {};
    /**
     * 下载任务状态变化时执行的回调
     * @param {DownloadTask} task 下载任务对象
     */


    this.stateChangeCb = function (task) {};
  };
  /**
   * 下载任务结束时调用（任务完成、任务取消、清除）
   * @param {Object} download 下载任务对象
   * @param {Object} resonse {status,message} 返回对象
   */


  var deleteTask = function (task) {
    delete __DOWNLOAD_TASK_LIST__[task.identify];
  };
  /**
   * 监听下载任务状态回调处理返回数据
   * 为避免暴露出去，内部调用时通过：
   * handlerCallback.call(task, options);
   */


  var handlerCallback = function (options) {
    this.filename = options.filename || this.filename;
    this.state = options.state || this.state;
    this.downloadedSize = options.downloadedSize || this.downloadedSize;
    this.totalSize = options.totalSize || this.totalSize; // identify
    // url
    // options
    // 下载任务状态变化回调函数，在下载任务状态发生变化时调用

    this.stateChangeCb(this); // 下载任务完成清除下载任务队列

    this.state == DownloadState.Finished && deleteTask(this); // 下载任务完成、下载任务失败，都调用业务回调

    if (this.state == DownloadState.Finished || this.state == DownloadState.Error) {
      this.completedCb(this);
    }
  };
  /**
   * DownloadState.Finished 下载任务完成，该事件桥 status返回 NATIVE_STATUS_CODE.OK
   * DownloadState.Error 下载任务发生异常，该事件桥 status返回 NATIVE_STATUS_CODE.PROCESS
   */


  var addStateChange = function (task) {
    bridge.call('Downloader', 'stateChanged', {
      identify: task.identify
    }, function (retObj) {
      var status = retObj.status;
      var message = retObj.message;
      var payload = retObj.payload;

      if (status === NATIVE_STATUS_CODE$2.OK || status === NATIVE_STATUS_CODE$2.PROCESS) {
        handlerCallback.call(task, payload.download);
      } else {
        deleteTask(task);
        logger$2.debug('====downloader-stateChanged====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
      }
    });
  };
  /**
   * 生成createDownload请求参数
   */


  var getDownloadOptions = function (task) {
    return {
      url: task.url,
      options: {
        identify: task.identify,
        method: task.method,
        data: task.data,
        header: task.header,
        filename: task.filename,
        priority: task.priority,
        timeout: task.timeout,
        retry: task.retry,
        retryInterval: task.retryInterval
      }
    };
  };

  _extends(DownloadTask.prototype, {
    /**
     * 开始下载任务
     */
    start: function () {
      var _this = this;

      bridge.call('Downloader', 'start', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          handlerCallback.call(_this, payload.download);
        } else {
          logger$2.debug('====downloader-start====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 暂停下载任务
     */
    pause: function () {
      var _this = this;

      bridge.call('Downloader', 'pause', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          handlerCallback.call(_this, payload.download);
        } else {
          logger$2.debug('====downloader-pause====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 恢复下载任务
     */
    resume: function () {
      var _this = this;

      bridge.call('Downloader', 'resume', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          handlerCallback.call(_this, payload.download);
        } else {
          logger$2.debug('====downloader-resume====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 取消下载任务，
     */
    abort: function () {
      var _this = this;

      bridge.call('Downloader', 'abort', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          handlerCallback.call(_this, payload.download);
          deleteTask(_this);
        } else {
          logger$2.debug('====downloader-abort====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 任务状态发生变化回调
     * @param {Function} stateChangeCb 下载任务状态变化回调，回调参数为task
     */
    stateChanged: function (cb) {
      typeof cb === 'function' && (this.stateChangeCb = cb);
    }
  });

  var downloader = {
    DownloadState: DownloadState,

    /**
     * 新建下载任务
     * @param {String} url 要下载文件资源地址
     * @param {Object} options 下载任务的参数，可选
     * @param {Function} completedCb 下载任务完成回调函数，回调参数为task
     */
    createDownload: function (url, options, completedCb) {
      if (typeof url != 'string') {
        return null;
      }

      options = options || {};
      options.url = url;
      options.completedCb = completedCb;
      var task = new DownloadTask(options);
      __DOWNLOAD_TASK_LIST__[task.identify] = task;
      var data = getDownloadOptions(task);
      bridge.call('Downloader', 'createDownload', data, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          handlerCallback.call(task, payload.download);
          addStateChange(task);
        } else {
          logger$2.debug('====downloader-createDownload====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
          deleteTask(task);
        }
      });
      return task;
    },

    /**
     * 开始所有下载任务
     */
    startAll: function () {
      bridge.call('Downloader', 'startAll', '', function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          payload.downloads.forEach(function (download) {
            var task = __DOWNLOAD_TASK_LIST__[download.identify];

            if (!task) {
              task = new DownloadTask(download);
              task.identify = download.identify;
            }

            handlerCallback.call(task, download);
          });
        } else {
          logger$2.debug('====downloader-startAll====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 清除下载任务
     * @param {DownloadState} state 状态
     */
    clear: function (state) {
      state = state || this.DownloadState.All;
      bridge.call('Downloader', 'clear', {
        state: state
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          payload.downloads.forEach(function (download) {
            var task = __DOWNLOAD_TASK_LIST__[download.identify];

            if (!task) {
              task = new DownloadTask(download);
              task.identify = download.identify;
            }

            handlerCallback.call(task, download);
            deleteTask(task);
          });
        } else {
          logger$2.debug('====downloader-clear====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 枚举下载任务
     * @param {DownloadState} state 状态
     * @param {Function} cb 回调
     */
    enumerate: function (state, cb) {
      state = state || this.DownloadState.All;
      bridge.call('Downloader', 'enumerate', {
        state: state
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$2.OK) {
          var tasks = [];
          payload.downloads.forEach(function (download) {
            var task = __DOWNLOAD_TASK_LIST__[download.identify];

            if (!task) {
              task = new DownloadTask(download);
              task.identify = download.identify;
            }

            handlerCallback.call(task, download);
            tasks.push(task);
          });
          cb(tasks);
        } else {
          logger$2.debug('====downloader-enumerate====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    }
  };
  /*
   * @Author: helin3
   * @Date: 2020-01-07 15:23:13
   * @LastEditors  : helin3
   * @LastEditTime : 2020-02-05 13:40:56
   * @Description: 文件上传
   */

  var logger$3 = utils.logger;
  var NATIVE_STATUS_CODE$3 = utils.NATIVE_STATUS_CODE;
  /**
   * 上传任务列表
   */

  var __UPLOAD_TASK_LIST__ = {};
  /**
   * 上传状态
   */

  var UploadState = {
    /**
     * 上传任务未开始
     */
    Undefined: -1001,

    /**
     * 枚举任务状态
     */
    All: -1,

    /**
     * 上传任务开始调度
     */
    Start: 0,

    /**
     * 上传任务开始请求,发送请求到服务器并等待服务器的响应
     */
    StartRequest: 1,

    /**
     * 上传任务请求已经接收,服务器返回响应，准备传输数据内容
     */
    ReadReceived: 2,

    /**
     * 上传任务接收数据,可多次触发此状态。
     */
    Received: 3,

    /**
     * 上传任务已完成（成功）
     */
    Finished: 4,

    /**
     * 上传任务已暂停
     */
    Pause: 5,

    /**
     * 上传任务发生异常
     */
    Error: 6
  };
  /**
   * 上传任务对象
   */

  var UploadTask = function (options) {
    /**
     * 上传任务TaskId
     */
    this.identify = utils.uuid('utask');
    this.options = options || {};
    this.url = this.options.url || '';
    /**
     * 上传任务每次上传的文件块大小（仅在支持断点续传的服务有效）
     * 数值类型，单位为Byte（字节），默认值为102400，若设置值小于等于0则表示不分块上传
     */

    this.blocksize = this.options.blocksize || 0;
    /**
     * 分块上传的大小
     * 单位为Kb，设置值小于等于0则不分块上传，默认为不分块上传
     * Android平台需设置分块上传才能准确触发statechanged返回上传进度，
     * 如果不设置分块上传则在开始后快速返回上传完成进度，而实际并没有上传完。
     * 注意：分块上传需要服务器支持，如果服务器不支持则会删除失败。
     */

    this.chunkSize = this.options.blocksize || 0;
    /**
     * 网络请求类型
     * 仅支持http协议的“POST”
     */

    this.method = this.options.method || 'POST';
    /**
     * 上传任务超时时间（暂不支持）
     * 数值类型，单位为s(秒)，默认值为120s。
     * 超时时间为服务器响应请求的时间（不是上传任务完成的总时间），如果设置为0则表示永远不超时。
     */

    this.timeout = this.options.timeout || 120;
    /**
     * 上传任务的优先级（暂不支持）
     * 数值类型，数值越大优先级越高，默认优先级值为0。
     */

    this.priority = this.options.priority || 0;
    /**
     * 上传任务重试次数（暂不支持）
     * 数值类型，默认为重试3次。
     */

    this.retry = this.options.retry || 3;
    /**
     * 上传任务重试间隔时间（暂不支持）
     * 数值类型，单位为s(秒)，默认值为30s。
     */

    this.retryInterval = this.options.retryInterval || 30;
    this.header = this.options.header || '';
    this.formData = '';
    /**
     * 上传任务完成后服务器返回的数据
     */

    this.responseText = '';
    /**
     * 已完成上传数据的大小
     */

    this.uploadedSize = 0;
    /**
     * 上传数据的总大小
     */

    this.totalSize = 0;
    /**
     * 上传任务当前状态
     */

    this.state = -1001;
    /**
     * 上传任务完成回调
     * @param {UploadTask} task 上传任务对象
     */

    this.completedCb = this.options.completedCb || function (task) {};
    /**
     * 上传任务状态变化时执行的回调
     * @param {UploadTask} task 上传任务对象
     */


    this.stateChangeCb = function (task) {};
  };
  /**
   * 上传任务结束时调用（任务完成、任务取消、清除）
   * @param {Object} UploadTask 上传任务对象
   * @param {Object} resonse {status,message} 返回对象
   */


  var deleteTask$1 = function (task) {
    delete __UPLOAD_TASK_LIST__[task.identify];
  };
  /**
   * 监听上传任务状态回调处理返回数据
   * 为避免暴露出去，内部调用时通过：
   * handlerCallback.call(task, options);
   */


  var handlerCallback$1 = function (options) {
    options = options || {};
    this.state = options.state || this.state;
    this.responseText = options.responseText || this.responseText;
    this.uploadedSize = options.uploadedSize || this.uploadedSize;
    this.totalSize = options.totalSize || this.totalSize;
    this.status = options.status;
    this.message = options.message;
    this.payload = options.payload; // identify
    // url
    // options
    // 上传任务状态变化回调函数，在上传任务状态发生变化时调用

    this.stateChangeCb(this); // 上传任务完成清除上传任务队列

    this.state == UploadState.Finished && deleteTask$1(this); // 上传任务完成、上传任务失败，都调用业务回调

    if (this.state == UploadState.Finished || this.state == UploadState.Error) {
      this.completedCb(this);
    }
  };
  /**
   * UploadState.Finished 上传任务完成，该事件桥 status返回 NATIVE_STATUS_CODE.OK
   * UploadState.Error 上传任务发生异常，该事件桥 status返回 NATIVE_STATUS_CODE.PROCESS
   */


  var addStateChange$1 = function (task) {
    bridge.call('Uploader', 'stateChanged', {
      identify: task.identify
    }, function (retObj) {
      var status = retObj.status;
      var message = retObj.message;
      var payload = retObj.payload;

      if (status === NATIVE_STATUS_CODE$3.OK || status === NATIVE_STATUS_CODE$3.PROCESS) {
        handlerCallback$1.call(task, payload.upload);
      } else {
        deleteTask$1(task);
        logger$3.debug('====uploader-stateChanged====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
      }
    });
  };
  /**
   * 生成createUpload请求参数
   */


  var getUploadOptions = function (task) {
    return {
      url: task.url,
      options: {
        identify: task.identify,
        blocksize: task.blocksize,
        chunkSize: task.chunkSize,
        method: task.method,
        header: task.header,
        timeout: task.timeout,
        priority: task.priority,
        retry: task.retry,
        retryInterval: task.retryInterval
      }
    };
  };

  _extends(UploadTask.prototype, {
    /**
     * 添加上传文件
     * @param {String} path
     * @param {UploadFileOption} options
     * key: (String 类型 )文件键名
     * 上传文件在上传任务中的键名，默认值为为文件名称。
     * 上传任务中如果已经存在相同key的上传文件或数据将导致添加文件失败。
     * name: (String 类型 )文件名称
     * 上传文件的名称，默认值为上传文件路径中的名称。
     * mime: (String 类型 )文件类型
     * 上传文件的类型（如图片文件为“image/jpeg”），默认值自动根据文件后缀名称生成。可不传值
     * @param {Function} cb 回调
     */
    addFile: function (path, options, cb) {
      var _this = this;

      var data = {
        path: path,
        options: options,
        identify: _this.identify
      };
      bridge.call('Uploader', 'addFile', data, cb);
    },

    /**
     * 加上传数据
     * @param {String} key 键名
     * @param {String} value 值
     * @param {Function} cb 回调
     * @returns
     */
    addData: function (key, value, cb) {
      var _this = this;

      var data = {
        key: key,
        value: value,
        identify: _this.identify
      };
      bridge.call('Uploader', 'addData', data, cb);
    },

    /**
     * 开始上传任务
     */
    start: function () {
      var _this = this;

      bridge.call('Uploader', 'start', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          handlerCallback$1.call(_this, payload.upload);
        } else {
          logger$3.debug('====uploader-start====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 暂停上传任务
     */
    pause: function () {
      var _this = this;

      bridge.call('Uploader', 'pause', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          handlerCallback$1.call(_this, payload.upload);
        } else {
          logger$3.debug('====uploader-pause====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 恢复上传任务
     */
    resume: function () {
      var _this = this;

      bridge.call('Uploader', 'resume', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          handlerCallback$1.call(_this, payload.upload);
        } else {
          logger$3.debug('====uploader-resume====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 取消上传任务，
     */
    abort: function () {
      var _this = this;

      bridge.call('Uploader', 'abort', {
        identify: _this.identify
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          handlerCallback$1.call(_this, payload.upload);
          deleteTask$1(_this);
        } else {
          logger$3.debug('====uploader-abort====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 任务状态发生变化回调
     * @param {Function} stateChangeCb 上传任务状态变化回调，回调参数为task
     */
    stateChanged: function (cb) {
      typeof cb === 'function' && (this.stateChangeCb = cb);
    },

    /**
    * 开始所有上传任务
    */
    startAll: function () {
      bridge.call('Uploader', 'startAll', '', function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          payload.uploads.forEach(function (upload) {
            var task = __UPLOAD_TASK_LIST__[upload.identify];

            if (!task) {
              task = new UploadTask(upload);
              task.identify = upload.identify;
            }

            handlerCallback$1.call(task, upload);
            addStateChange$1(task);
          });
        } else {
          logger$3.debug('====uploader-startAll====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + JSON.stringify(payload));
        }
      });
    }
  });

  var uploader = {
    UploadState: UploadState,

    /**
     * 新建上传任务
     * @param {String} url 要上传文件资源地址
     * @param {Object} options 上传任务的参数，可选
     * @param {Function} completedCb 上传任务完成回调函数，回调参数为task
     */
    createUpload: function (url, options, completedCb) {
      if (typeof url != 'string') {
        return null;
      }

      options = options || {};
      options.url = url;
      options.completedCb = completedCb;
      var task = new UploadTask(options);
      __UPLOAD_TASK_LIST__[task.identify] = task;
      var data = getUploadOptions(task);
      bridge.call('Uploader', 'createUpload', data, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          handlerCallback$1.call(task, payload.upload);
          addStateChange$1(task);
        } else {
          logger$3.debug('====uploader-createUpload====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
          deleteTask$1(task);
        }
      });
      return task;
    },

    /**
     * 开始所有上传任务
     */
    startAll: function () {
      bridge.call('Uploader', 'startAll', '', function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          payload.uploads.forEach(function (upload) {
            var task = __UPLOAD_TASK_LIST__[upload.identify];

            if (!task) {
              task = new UploadTask(upload);
              task.identify = upload.identify;
            }

            handlerCallback$1.call(task, upload);
            addStateChange$1(task);
          });
        } else {
          logger$3.debug('====uploader-startAll====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + JSON.stringify(payload));
        }
      });
    },

    /**
     * 清除上传任务
     * @param {UploadState} state 状态
     */
    clear: function (state) {
      state = state || this.UploadState.All;
      bridge.call('Uploader', 'clear', {
        state: state
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          payload.uploads.forEach(function (upload) {
            var task = __UPLOAD_TASK_LIST__[upload.identify];

            if (!task) {
              task = new UploadTask(upload);
              task.identify = upload.identify;
            }

            handlerCallback$1.call(task, upload);
            deleteTask$1(task);
          });
        } else {
          logger$3.debug('====uploader-clear====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    },

    /**
     * 枚举上传任务
     * @param {UploadState} state 状态
     * @param {Function} cb 回调
     */
    enumerate: function (state, cb) {
      state = state || this.UploadState.All;
      bridge.call('Uploader', 'enumerate', {
        state: state
      }, function (retObj) {
        var status = retObj.status;
        var message = retObj.message;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$3.OK) {
          var tasks = [];
          payload.uploads.forEach(function (upload) {
            var task = __UPLOAD_TASK_LIST__[upload.identify];

            if (!task) {
              task = new UploadTask(upload);
              task.identify = upload.identify;
            }

            handlerCallback$1.call(task, upload);
            tasks.push(task);
          });
          cb(tasks);
        } else {
          logger$3.debug('====uploader-enumerate====: \n status: ' + status + ',\n message: ' + message + ',\n payload: ' + payload);
        }
      });
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors  : chencm
   * @LastEditTime : 2020-01-02 14:58:45
   * @Description: 设备信息
   */

  var device = {
    /**
     * @description 网络连接状态未知
     */
    CONNECTION_UNKNOW: 0,

    /**
     * @description 未连接网络
     */
    CONNECTION_NONE: 1,

    /**
     * @description 无线WIFI网络
     */
    CONNECTION_WIFI: 2,

    /**
     * @description GPRS
     */
    CONNECTION_GPRS: 3,

    /**
     * @description 蜂窝移动2G网络
     */
    CONNECTION_CELL2G: 5,

    /**
     * @description 蜂窝移动3G网络
     */
    CONNECTION_CELL3G: 6,

    /**
     * @description 蜂窝移动4G网络
     */
    CONNECTION_CELL4G: 7,

    /**
     * @description 获取系统版本信息
     * @returns {String} payload:{versionCode:xxx}
     */
    version: function (cb) {
      bridge.call('SystemInfo', 'getAppversion', {}, cb);
    },

    /**
     * @description 获取应用横竖屏状态
     * @type {Function}
     * @returns {Number} payload:{orientation:xxx}
     * { 0:未知; 1,2: 竖屏; 3, 4: 横屏 }
     */
    getOrientation: function (cb) {
      bridge.call('SystemInfo', 'getOrientation', {}, cb);
    },

    /**
     * @description 获取应用的安全区域信息
     * @type {Function}
     * @returns {Number} payload:{safeAreaInsets:xxx}
     * {"top":"","left":"","bottom":"","right":""}
     */
    getSafeAreaInsets: function (cb) {
      bridge.call('SystemInfo', 'getSafeAreaInsets', {}, cb);
    },

    /**
     * @description 获取应用的状态栏高度信息
     * @type {Function}
     * @returns {Float} payload:{statusbarHeight:xxx}
     */
    getStatusbarHeight: function (cb) {
      bridge.call('SystemInfo', 'getStatusbarHeight', {}, cb);
    },

    /**
     * @description 获取应用的状态栏样式信息
     * @type {Function}
     * @returns {String} payload:{style:xxx}
     * {default:黑色文字 ，light：白色文字 ，dark：（ios13支持暗黑模式）文字白色}
     */
    getStatusBarStyle: function (cb) {
      bridge.call('SystemInfo', 'getStatusBarStyle', {}, cb);
    },

    /**
     * @description 获取应用的状态栏样式信息
     * @type {Function}
     * @returns {Dictionary} payload:{xxx:xxx}
     *
     * name string 系统的名称 iOS| xxx
     *
     * osvendor string 系统的供应商信息
     *
     * version string 系统版本信息
     *
     * language string 语种
     *
     * height float 屏幕高度物理分辨率
     *
     * width float 屏幕宽度物理分辨率
     *
     * resolutionHeight float 屏幕高度逻辑分辨率
     *
     * resolutionWidth float 屏幕宽度逻辑分辨率
     *
     * scale float 逻辑分辨率与物理分辨率的缩放比例
     *
     * orientation int 获取应用横竖屏状态
     *
     * statusbarHeight float 状态栏高度
     *
     * safeAreaInsets Dictionary 应用的安全区域{"bottom" : 34,"top" : 44,"right" : 0,"left" : 0},
     *
     * vendor string 设备的生产厂商 iPhone Inc | xxx
     *
     * model string 设备的型号  iPhone | xxx
     *
     * innerVersion string 客户端FOX运行环境的内部版本号
     *
     * appid string 当前应用的APPID(bundleID)户
     *
     * appName string 客户端的应用名称
     *
     * versionCode string 客户端的版本号
     *
     * launcher string 应用启动来源
     *
     * arguments Dictionary 第三方程序调用时传递给程序的参数
     */
    getSystemInfo: function (cb) {
      bridge.call('SystemInfo', 'getSystemInfo', {}, cb);
    },

    /**
     * @description 获取应用的设备指纹-唯一标识信息
     * @type {Function}
     * @returns {String} payload:{uuid:xxx} 设备唯一标识别
     */
    getUUID: function (cb) {
      bridge.call('SystemInfo', 'getUUID', {}, cb);
    },

    /**
     * @description 获取应用的wifi开启状态
     * @type {Function}
     * @returns {String} payload:{wifiEnabled:boolean}
     * true/false
     */
    getWifiOpenStatus: function (cb) {
      bridge.call('SystemInfo', 'getWifiOpenStatus', {}, cb);
    },

    /**
     * @description 设置程序快捷方式图标上显示的角标数字
     * @type {Function}
     * @param {Object} data:{number: "5"} 设置程序快捷方式图标上显示的角标数字，android 仅支持小米，华为，部分支持oppo，vivo
     * @returns void
     */
    setBadgeNumber: function (data, cb) {
      bridge.call('SystemInfo', 'setBadgeNumber', data, cb);
    },

    /**
     * @description 设置状态栏样式
     * @type {Function}
     * @param {String} stl 状态栏样式 [defaul：黑色字, light：白色字 ,dark：白色字(ios13支持)]
     * @returns void
     */
    setStatusBarStyle: function (stl, cb) {
      bridge.call('SystemInfo', 'setStatusBarStyle', stl, cb);
    },

    /**
     * @description 拨打电话
     * @type {Function}
     * @param {String} 电话号码
     * @returns void
     */
    dial: function (num, cb) {
      bridge.call('Application', 'dial', num, cb);
    },
    //获取底部高度
    getNavigationbarHeight: function getNavigationbarHeight(cb) {
      bridge.call('SystemInfo', 'getNavigationbarHeight', {}, cb);
    },
    /**
     * 结束app
     */
    appFinish: function (cb) {
      bridge.call('Application', 'appFinish', cb);
    },

    /**
     * 获取app相关信息
     */
    getSystemAppInfo: function (cb) {
          bridge.call('SystemInfo', 'getSystemAppInfo', "", cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:16
   * @LastEditors  : chencm
   * @LastEditTime : 2020-01-15 15:35:36
   * @Description: 网络信息
   */

  var networkinfo = {
    /**
     * @description 网络连接状态未知
     */
    CONNECTION_UNKNOW: 0,

    /**
     * @description 未连接网络
     */
    CONNECTION_NONE: 1,

    /**
     * @description 无线WIFI网络
     */
    CONNECTION_WIFI: 2,

    /**
     * @description GPRS
     */
    CONNECTION_GPRS: 3,

    /**
     * @description 有线网络
     */
    CONNECTION_ETHERNET: 4,

    /**
     * @description 蜂窝移动2G网络
     */
    CONNECTION_CELL2G: 5,

    /**
     * @description 蜂窝移动3G网络
     */
    CONNECTION_CELL3G: 6,

    /**
     * @description 蜂窝移动4G网络
     */
    CONNECTION_CELL4G: 7,

    /**
     * @description 获取当前网络类型
     * @type {Function}
     * @returns {Number,String}  payload:{type:(Number)key,msg:(String)value}
     * {0:未知网络,1:无网络连接,2:wifi连接,3:GPRS连接,4:2.75G EDGE,5:2G,6:3G,7:4G,8:HRPD,9:3.5G HSDPA,10:3.5G HSUPA}
     */
    getCurrentType: function (cb) {
      bridge.call('SystemInfo', 'getCurrentType', {}, function (ret) {
        var networkType;
        var currentType = ret.payload.currentType.type;

        if (currentType === 0) {
          networkType = networkinfo.CONNECTION_UNKNOW;
        } else if (currentType === 1) {
          networkType = networkinfo.CONNECTION_NONE;
        } else if (currentType === 2) {
          networkType = networkinfo.CONNECTION_WIFI;
        } else if (currentType === 3) {
          networkType = networkinfo.CONNECTION_GPRS;
        } else if (currentType === 11) {
          networkType = networkinfo.CONNECTION_ETHERNET;
        } else if (currentType === 5) {
          networkType = networkinfo.CONNECTION_CELL2G;
        } else if (currentType === 6) {
          networkType = networkinfo.CONNECTION_CELL3G;
        } else if (currentType === 7) {
          networkType = networkinfo.CONNECTION_CELL4G;
        } else {
          networkType = 'other';
        }

        typeof cb === 'function' && cb({
          status: ret.status,
          message: ret.message,
          payload: {
            networkType: networkType
          }
        });
      });
    },

    /**
     * @description 获取IP地址信息
     * @type {Function}
     * @returns {String}  payload:{ipAddress:xxx}
     */
    getIpAddress: function (cb) {
      bridge.call('SystemInfo', 'getIpAddress', '', cb);
    }
    /**
     * @description 获取MAC地址信息
     * @type {Function}
     * @returns {String} payload:{macAddress:xxx}
     */
    // getMacAddress: cb => {
    //   core.call('SystemInfo', 'getMacAddress', {}, cb);
    // }

  };
  /*
   * @Author: helin3
   * @Date: 2020-01-16 10:00:23
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-16 16:04:19
   * @Description: 屏幕（亮度、截屏事件）
   */

  var logger$4 = utils.logger;
  var SdkError$2 = utils.SdkError;
  /**
   * 监听事件
   */

  var EventCallbacks = {};
  var KeyType = {
    UserCaptureScreen: 'UserCaptureScreen'
  };
  var screen = {
    /**
     * @description 设置屏幕亮度
     * @param {Number} value 屏幕亮度值，范围 0~1，0 最暗，1 最亮
     * @param {Function} cb 回调
     */
    setScreenBrightness: function (value, cb) {
      bridge.call('Screen', 'setBrightness', {
        value: value
      }, cb);
    },

    /**
     * @description 获取屏幕亮度
     * @param {Function} cb 回调
     * payload value 屏幕亮度值，范围 0~1，0 最暗，1 最亮
     */
    getScreenBrightness: function (cb) {
      bridge.call('Screen', 'getBrightness', '', cb);
    },

    /**
     * @description 设置是否保持常亮状态。仅在当前应用生效，离开应用后设置失效。
     * @param {Boolean} keepScreenOn 保持屏幕长亮
     * @param {Function} cb 回调
     */
    setKeepScreenOn: function (keepScreenOn, cb) {
      bridge.call('Screen', 'setWakelock', {
        keepScreenOn: keepScreenOn
      }, cb);
    },

    /**
     * 监听用户主动截屏事件，用户使用系统截屏按键截屏时触发此事件
     * @param {Function} cb 回调
     * @param {String} global 全局标识 0/true:为全局监听即所有webview都监听，1/false/默认:为当前webview监听
     */
    onUserCaptureScreen: function (cb, global) {
      if (global === void 0) global = '1';
      var event = KeyType.UserCaptureScreen;
      var evts = EventCallbacks[event] = EventCallbacks[event] || [];
      var flag = evts.some(function (item) {
        return item.fn === cb;
      });

      if (flag) {
        throw new SdkError$2('69002', '事件监听上已绑定过当前回调，请勿重复绑定！');
      }

      var cbid = bridge.call('Screen', 'onUserCaptureScreen', {
        eventName: event,
        global: global
      }, cb);
      EventCallbacks[event].push({
        cbid: cbid,
        fn: cb
      });
    },

    /**
     * 移除键盘监听事件
     * @param {Function} cb 移除监听的方法引用
     */
    offUserCaptureScreen: function (cb) {
      var event = KeyType.UserCaptureScreen;
      var evts = EventCallbacks[event] = EventCallbacks[event] || [];
      var someFlag = evts.some(function (item, index) {
        var flag = item.fn === cb;

        if (flag) {
          bridge.call('Screen', 'offUserCaptureScreen', {
            callbackid: item.cbid
          }, function () {}); // 移除事件监听时存储的业务回调对象

          evts.splice(index, 1); // 删除桥接层存储的监听回调方法

          bridge.removeCb(item.cbid);
        }

        return flag;
      });

      if (!someFlag) {
        logger$4.debug('当前方法引用未注册过监听或已被移除！');
      }
    },

    /**
     * 针对当前webview截屏
     * @param {object} 回调
     * @param {Function} cb 回调
     */
    capture: function (data, cb) {
      bridge.call('Application', 'capture', data, cb);
    },

    /**
    * IOS针对当前webview，截取已为手机端适配的web页面，截取纵向长图
    * @param {object} 回调
    * @param {Function} cb 回调
    */
    captureLongPic: function (data, cb) {
      bridge.call('Application', 'captureLongPic', data, cb);
    },

    /**
    * android 禁止截屏
    * @param {Function} cb 回调
    */
    forbidScreenshot: function(cb){
      bridge.call('Screen', 'forbidScreenshot', "", cb);
    },

    /**
    * android 允许截屏
    * @param {Function} cb 回调
    */
    allowScreenshot: function(cb){
      bridge.call('Screen', 'allowScreenshot', "", cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:16
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-13 19:09:28
   * @Description: 数据缓存
   */

  var storage = {
    /**
     * 根据Key值获取存储数据
     * @param {string} key key值
     * @param {Function} cb 回调
     */
    getItem: function (key, cb) {
      return bridge.call('Storage', 'getItem', key, function (res) {
        // 注：由于bridge在解析payload数据时，默认已做了一次字符串转JSON，故此处无需再次解析
        cb(res);
      });
    },

    /**
     * 设置Key/Value存储值
     * @param {string} key key值
     * @param {string} key value值
     * @param {Function} cb 回调
     */
    setItem: function (key, value, cb) {
      var data = {};
      data[key] = JSON.stringify(value);
      return bridge.call('Storage', 'setItem', data, cb);
    },

    /**
     * 删除指定Key值对应的键值对
     * @param {string} key key值
     * @param {Function} cb 回调
     */
    removeItem: function (key, cb) {
      return bridge.call('Storage', 'removeItem', key, cb);
    },

    /**
     * 清空存储
     * @param {Function} cb 回调
     */
    clear: function (cb) {
      return bridge.call('Storage', 'clear', '', cb);
    },
    /**
     * 获取部分本地信息存储
     * @param {Function} cb 回调
     */
     getLocalUserInfo: function (data,cb) {
      return bridge.call('Storage', 'getLocalUserInfo', data, cb);
     }

  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 11:29:42
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-13 19:32:46
   * @Description: 剪贴板
   */

  var clipboard = {
    /**
     * 设置系统剪贴板的内容
     * @param {String} data 数据
     * @param {Function} cb 回调
     * @returns
     */
    setData: function (data, cb) {
      bridge.call('PastBoard', 'setClipboardData', data, cb);
    },

    /**
     * 获取系统剪贴板内容。
     * @param {Function} cb 回调
     * @returns
     * {Object} payload {data}
     */
    getData: function (cb) {
      bridge.call('PastBoard', 'getClipboardData', '', cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors  : chencm
   * @LastEditTime : 2020-01-03 10:15:02
   * @Description: 应用运行环境
   */

  var runtime = {
    /**
     * @description 容器-文档在线查看
     * @type {Function}
     * @param {String} url  在线文档地址
     */
    openDoc: function (url, cb) {
      bridge.call('Application', 'openDocument', url, cb);
    },

    /**
     * @description 调用第三方程序打开指定的文件(ios可以直接打开)
     * @type {Function}
     * @param {String} url  离线文档地址
     */
    openFile: function (url, cb) {
      bridge.call('Application', 'openFile', url, cb);
    },

    /**
     * @description 调用第三方程序打开指定的URL，支持打开safari打开 网页，以及app
       * @type {Function}
     * @param {String} url 地址
     */
    openURL: function (url, cb) {
      bridge.call('Application', 'openURL', url, cb);
    },

    /**
     * @description 使用内置Webview窗口打开URL
     * @type {Function}
     * @param {String} url 地址
     */
    openWeb: function (url, cb) {
      bridge.call('Application', 'openWeb', url, cb);
    },

    /**
     * @description 获取应用启动来源，第三方程序调用时传递给程序的参数
     * @type {Function}
     */
    getLauncherPram: function (cb) {
      bridge.call('Application', 'getLauncherPram', {}, cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-31 10:56:10
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-17 14:45:54
   * @Description: IO文件操作
   */

  var NATIVE_STATUS_CODE$4 = utils.NATIVE_STATUS_CODE;
  var extendClazz$1 = utils.extendClazz;
  /**
   * 文件系统定义（支持4种）
   * @param {String} name 文件系统名称
   * PRIVATE_WWW、PRIVATE_DOC
   * PUBLIC_DOCUMENTS、PUBLIC_DOWNLOADS
   * @param {Object} root {name, fullPath, remoteURL}
   */

  var FileSystem = function (name, root) {
    this.name = name || null;
    this.root = null;

    if (root) {
      var name$1 = root.name;
      var fullPath = root.fullPath;
      var remoteURL = root.remoteURL;
      this.root = new DirectoryEntry(name$1, fullPath, remoteURL, this);
    }
  };
  /**
   * 文件系统中的文件操作对象，用于管理特定的本地文件或目录
   * @param {String} isFile
   * @param {String} isDirectory
   * @param {String} name
   * @param {String} fullPath
   * @param {String} remoteURL
   * @param {FileSystem} fileSystem
   */


  var Entry = function (isFile, isDirectory, name, fullPath, remoteURL, fileSystem) {
    /**
     * 文件操作对象的是否为文件，FileEntry对象固定其值为true
     */
    this.isFile = isFile;
    /**
     * 文件操作对象是否为目录，FileEntry对象固定其值为false
     */

    this.isDirectory = isDirectory;
    /**
     * 文件操作对象的名称，不包括路径
     */

    this.name = name || '';
    /**
     * 文件操作对象的完整路径，文件系统的绝对路径
     */

    this.fullPath = fullPath || '';
    /**
     * 文件远程URL地址，暂且值是扩展本地相对路径，如：_doc/xxx/xxx.doc
     */

    this.remoteURL = remoteURL || null;
    /**
     * 文件操作对象所属的文件系统对象，参考FileSystem
     */

    this.fileSystem = fileSystem || null;
  };
  /**
   * 定义文件操作对象基础方法
   */


  _extends(Entry.prototype, {
    /**
     * 获取目录/文件的属性
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @param {Boolean} recursive 是否递归计算目录信息
     * @returns
     */
    getMetadata: function (successCb, failCb, recursive) {
      if (recursive === void 0) recursive = false;
      var data = {
        srcTarget: this.fullPath,
        recursive: recursive
      };
      bridge.call('File', 'getMetadata', data, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          typeof successCb === 'function' && successCb(payload);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 移动本地文件
     * @param {String} dest 目标文件绝对路径
     * @param {String} newName 文件名
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     */
    moveTo: function (dest, newName, successCb, failCb) {
      var this$1 = this;
      var data = {
        srcPath: this.fullPath,
        destPath: dest,
        newName: newName
      };
      bridge.call('File', 'moveTo', data, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          var isDirectory = payload.isDirectory;
          var name = payload.name;
          var fullPath = payload.fullPath;
          var remoteURL = payload.remoteURL;
          var entry = isDirectory ? new DirectoryEntry(name, fullPath, remoteURL, this$1.fileSystem) : new FileEntry(name, fullPath, remoteURL, this$1.fileSystem);
          typeof successCb === 'function' && successCb(entry);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 复制本地文件
     * @param {String} dest 目标文件绝对路径
     * @param {String} newName 文件名
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     */
    copyTo: function (dest, newName, successCb, failCb) {
      var this$1 = this;
      var data = {
        srcPath: this.fullPath,
        destPath: dest,
        newName: newName
      };
      bridge.call('File', 'copyTo', data, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          var isDirectory = payload.isDirectory;
          var name = payload.name;
          var fullPath = payload.fullPath;
          var remoteURL = payload.remoteURL;
          var entry = isDirectory ? new DirectoryEntry(name, fullPath, remoteURL, this$1.fileSystem) : new FileEntry(name, fullPath, remoteURL, this$1.fileSystem);
          typeof successCb === 'function' && successCb(entry);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 删除本地文件
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @param {Boolean} recursive 递归删除，可选，默认false
     * @returns
     */
    remove: function (successCb, failCb, recursive) {
      if (recursive === void 0) recursive = false;
      var data = {
        srcTarget: this.fullPath,
        recursive: recursive
      };
      bridge.call('File', 'remove', data, function (retObj) {
        var status = retObj.status;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          typeof successCb === 'function' && successCb(retObj);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 获取文件路径转换为本地路径URL地址
     */
    toLocalURL: function () {
      return 'file://' + this.fullPath;
    },

    /**
     * 获取目录路径转换为网络路径URL地址
     */
    toRemoteURL: function () {
      return this.remoteURL;
    }
  });
  /**
   * 文件系统中的文件操作对象，用于管理特定的本地文件
   * @param {String} name
   * @param {String} fullPath
   * @param {String} remoteURL
   * @param {FileSystem} fileSystem
   */


  var FileEntry = function (name, fullPath, remoteURL, fileSystem) {
    Entry.call(this, true, false, name, fullPath, remoteURL, fileSystem);
  }; // FileEntry继承于Entry


  extendClazz$1(Entry, FileEntry);
  /**
   * 文件操作对象，基于文件上的特有方法
   */

  _extends(FileEntry.prototype, {
    /**
     * 获取文件摘要信息
     * @param {Function} cb 回调
     * @returns
     */
    getFileDigestInfo: function (digestAlgorithm, successCb, failCb) {
      if (digestAlgorithm === void 0) digestAlgorithm = 'md5';
      var data = {
        filePath: this.fullPath,
        digestAlgorithm: digestAlgorithm
      };
      bridge.call('File', 'getFileDigestInfo', data, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          typeof successCb === 'function' && successCb(payload);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    }
  });
  /**
   * 文件系统中的文件操作对象，用于管理特定的本地目录
   * @param {Boolean} isDirectory
   * @param {String} name
   * @param {String} fullPath
   * @param {String} remoteURL
   * @param {FileSystem} fileSystem
   */


  var DirectoryEntry = function (name, fullPath, remoteURL, fileSystem) {
    Entry.call(this, false, true, name, fullPath, remoteURL, fileSystem);
  }; // DirectoryEntry继承于Entry


  extendClazz$1(Entry, DirectoryEntry);
  /**
   * 目录操作对象，独有方法
   */

  _extends(DirectoryEntry.prototype, {
    /**
     * 获取目录的属性
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @param {Boolean} recursive 是否递归查询,默认false
     * @returns
     */
    getFileListMetadata: function (successCb, failCb, recursive) {
      if (recursive === void 0) recursive = false;
      var data = {
        filePath: this.fullPath,
        recursive: recursive
      };
      bridge.call('File', 'getFileListMetadata', data, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          typeof successCb === 'function' && successCb(payload);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 创建或打开子目录
     * @param {String} path 要操作目录相对于当前目录的地址
     * @param {Object} flag {create: false, exclusive: false}
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     */
    getDirectory: function (path, flag, successCb, failCb) {
      var this$1 = this;
      flag = _extends({
        create: false,
        exclusive: false
      }, flag || {});
      var data = {
        fullPath: this.fullPath,
        path: path,
        flag: flag
      };
      bridge.call('File', 'getDirectory', data, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          var name = payload.name;
          var fullPath = payload.fullPath;
          var remoteURL = payload.remoteURL;
          var entry = new DirectoryEntry(name, fullPath, remoteURL, this$1.fileSystem);
          typeof successCb === 'function' && successCb(entry);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 创建或打开文件
     * @param {String} path 要操作目录相对于当前目录的地址
     * @param {Object} flag {create: false, exclusive: false}
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     */
    getFile: function (path, flag, successCb, failCb) {
      var this$1 = this;
      flag = _extends({
        create: false,
        exclusive: false
      }, flag || {});
      var data = {
        fullPath: this.fullPath,
        path: path,
        flag: flag
      };
      bridge.call('File', 'getFile', data, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          var name = payload.name;
          var fullPath = payload.fullPath;
          var remoteURL = payload.remoteURL;
          var entry = new FileEntry(name, fullPath, remoteURL, this$1.fileSystem);
          typeof successCb === 'function' && successCb(entry);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    }
  });

  var io = {
    /**
     * 应用运行资源目录常量
     */
    PRIVATE_WWW: 1,

    /**
     * 应用私有文档目录常量
     */
    PRIVATE_DOC: 2,

    /**
     * 程序公用文档目录常量
     */
    PUBLIC_DOCUMENTS: 3,

    /**
     * 程序公用下载目录常量
     */
    PUBLIC_DOWNLOADS: 4,

    /**
     * 将平台绝对路径转换成本地URL路径
     * @param {String} path 平台绝对路径，如：/var/xxx/doc/xxx/xxx.txt
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     * {String} payload 本地URL路径 _doc/xxx/xxx.txt
     */
    convertAbsoluteFileSystem: function (path, successCb, failCb) {
      bridge.call('File', 'convertAbsoluteFileSystem', path, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          typeof successCb === 'function' && successCb(payload.path);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 将本地URL路径转换成平台绝对路径
     * @param {String} path 本地URL路径，如：_doc/xxx/xxx.txt
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     * {String} payload 平台绝对路径 /var/xxx/doc/xxx/xxx.txt
     */
    convertLocalFileSystemURL: function (url, successCb, failCb) {
      bridge.call('File', 'convertLocalFileSystemURL', url, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          typeof successCb === 'function' && successCb(payload.path);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 快速获取指定的目录或文件操作对象，如通过URL值“_www/test.html”可直接获取文件
     * @param {String} url 要操作文件或目录的URL地址
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     */
    resolveLocalFileSystemURL: function (url, successCb, failCb) {
      bridge.call('File', 'resolveLocalFileSystemURL', url, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          var isDirectory = payload.isDirectory;
          var name = payload.name;
          var fullPath = payload.fullPath;
          var remoteURL = payload.remoteURL;
          var fsName = payload.fsName;
          var fsRoot = payload.fsRoot;
          var fs = new FileSystem(fsName, fsRoot);
          var entry = isDirectory ? new DirectoryEntry(name, fullPath, remoteURL, fs) : new FileEntry(name, fullPath, remoteURL, fs);
          typeof successCb === 'function' && successCb(entry);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    },

    /**
     * 请求本地文件系统（返回绝对路径）
     *  PRIVATE_WWW:  _www/
     *  PRIVATE_DOC:  _doc/
     *  PUBLIC_DOCUMENTS:  _documents/
     *  PUBLIC_DOWNLOADS:  _downloads/
     * @param {Number} type 本地文件系统常量
     * @param {Function} successCb 回调
     * @param {Function} failCb 回调
     * @returns
     */
    requestFileSystem: function (type, successCb, failCb) {
      bridge.call('File', 'requestFileSystem', {
        type: type
      }, function (retObj) {
        var status = retObj.status;
        var payload = retObj.payload;

        if (status === NATIVE_STATUS_CODE$4.OK) {
          var name = payload.name;
          var root = payload.root;
          var fs = new FileSystem(name, root);
          typeof successCb === 'function' && successCb(fs);
        } else {
          typeof failCb === 'function' && failCb(retObj);
        }
      });
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-31 10:56:10
   * @LastEditors  : helin3
   * @LastEditTime : 2019-12-31 14:38:16
   * @Description: 压缩/解压
   */

  var zip = {
    /**
     * 压缩生成Zip文件
     * @param {String} src 源文件路径或目录
     * @param {String} zipfile 压缩后保存的Zip文件路径
     * @param {Function} cb 回调
     * @returns
     */
    compress: function (src, zipfile, cb) {
      var data = {
        src: src,
        zipfile: zipfile
      };
      bridge.call('Zip', 'compress', data, cb);
    },

    /**
     * 解压缩Zip文件
     * @param {String} zipfile 要压缩的源文件路径，支持文件路径或目录
     * @param {String} target 压缩后保存的Zip文件路径
     * @param {Function} cb 回调
     * @returns
     */
    decompress: function (zipfile, target, cb) {
      var data = {
        target: target,
        zipfile: zipfile
      };
      bridge.call('Zip', 'decompress', data, cb);
    },

    /**
     * 图片压缩转换
     * @param {Object} options 参数
     * @param {Function} cb 回调
     * @returns
     */
    compressImage: function (options, cb) {
      bridge.call('Zip', 'compressImage', options, cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 11:49:24
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-17 15:17:51
   * @Description: 系统软键盘
   */

  var SdkError$3 = utils.SdkError;
  /**
   * 监听键盘事件
   */

  var EventCallbacks$1 = {};
  var KeyType$1 = {
    KeyboardHeightChange: 'KeyboardHeightChange'
  };
  var key = {
    /**
     * 显示系统软键盘
     * @param {Function} cb 回调
     */
    showSoftKeybord: function (cb) {
      bridge.call('Keyboard', 'showSoftKeybord', '', cb);
    },

    /**
     * 隐藏系统软键盘
     * @param {Function} cb 回调
     */
    hideSoftKeybord: function (cb) {
      bridge.call('Keyboard', 'hideSoftKeybord', '', cb);
    },

    /**
     * 监听系统键盘事件
     * @param {String} event 事件名
     * @param {Function} cb 回调
     * @param {String} global 全局标识 0/true:为全局监听即所有webview都监听，1/false/默认:为当前webview监听
     */
    onKeyboardHeightChange: function (cb, global) {
      if (global === void 0) global = '1';
      var event = KeyType$1.KeyboardHeightChange;
      var evts = EventCallbacks$1[event] = EventCallbacks$1[event] || [];
      var flag = evts.some(function (item) {
        return item.fn === cb;
      });

      if (flag) {
        throw new SdkError$3('69002', '事件监听上已绑定过当前回调，请勿重复绑定！');
      }

      var cbid = bridge.call('Keyboard', 'onKeyboardHeightChange', {
        eventName: event,
        global: global
      }, cb);
      EventCallbacks$1[event].push({
        cbid: cbid,
        fn: cb
      });
    },

    /**
     * 移除键盘监听事件
     * @param {Function} cb 回调
     */
    offKeyboardHeightChange: function (cb) {
      var event = KeyType$1.KeyboardHeightChange;
      var evts = EventCallbacks$1[event] = EventCallbacks$1[event] || [];
      evts.some(function (item, index) {
        var flag = item.fn === cb;

        if (flag) {
          bridge.call('Keyboard', 'offKeyboardHeightChange', item.cbid || '', function () {}); // 移除事件监听时存储的业务回调对象

          evts.splice(index, 1); // 删除桥接层存储的监听回调方法

          bridge.removeCb(item.cbid);
        }

        return flag;
      });
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 13:41:17
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-13 14:30:09
   * @Description: 密码键盘
   */

  var pwdkey = {
    MD5: 'md5',
    AES: 'aes',
    RSA: 'rsa',
    SM2: 'sm2',
    SM4: 'sm4',

    /**
     * 显示
     * @param {Object} data 请求参数
     * @param {Function} cb 回调
     */
    show: function (options, cb) {
      if (options === void 0) options = {};
      var data = {
        type: 'md5',
        number: false,
        confusion: 1,
        max: 100,
        closed: true,
        presses: true,
        input: '',
        encrypt: '',
        sm2Px: '',
        sm2Py: ''
      };

      _extends(data, options);

      bridge.call('PasswordKeyboard', 'show', data, cb);
    },

    /**
     * 隐藏密码键盘
     * @param {Object} data 请求参数
     * @param {Function} cb 回调
     * @returns {text, cipherText}
     */
    hide: function (cb) {
      bridge.call('PasswordKeyboard', 'hide', '', cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-02 11:46:58
   * @Description: 媒体 - 图片
   */

  var gallery = {
    /**
     * @description 图片预览
     * @type {Function}
     * @param {String} data
     * {"current":"1","urls":["图片路径1","图片路径2"],"indicator ":"default"}
     * current string 图片索引，默认显示第几张
     * urls  Array  请求参数字符串或键值对，可以是外网图片或者本地图片
     * indicator  String  图片指示器样式，可取值："default" - 底部圆点指示器； "number" - 顶部数字指示器； "none" - 不显示指示器。
     * longPressActions  Object   长按图片显示操作菜单，如不填默认为保存图片
     * @returns {Number}
     * {
     *    index       float   用户长按图片的索引值
     *    tapIndex  float  用户点击按钮列表的索引值
     * }
     */
    previewImage: function (data, cb) {
      bridge.call('Media', 'previewImage', data, cb);
    },

    /**
     * @description 预览图片 从系统相册选择文件（图片或视频）
     * @type {Function}
     * @param {String} data
     * {
     * "pickType":"2",// 1:单选 2:多选
     * "options":{
     *    "filter":"image", //文件类型 image:图片 video:视频 none:不过滤
     *    "maximum":"6"
     * }
     * @returns {String}
     * event  Array[String] 多选返回字段，为多路径的数组
     * file  string        单选返回字段，为文件路径
     */
    pick: function (url, cb) {
      bridge.call('Media', 'pick', url, cb);
    },

    /**
     * @description 保存图片到相册
     * @type {Function}
     * @param {String} url  图片路径
     */
    save: function (url, cb) {
      bridge.call('Media', 'save', url, cb);
    },

    /**
     * @description 保存图片到相册
     * @type {Function}
     * @param {String} url  base64字符串
     */
    save64: function (url, cb) {
      bridge.call('Media', 'save64', url, cb);
    },

    /**
     * @description 图片裁剪
     * @type {Function}
     * @param {String} url
     */
    pickSingleImageWithEdit: function (data, cb) {
      bridge.call('Media', 'pickSingleImageWithEdit', data, cb);
    },

    /**
     * @description 图片转Base64
     * @param {String} url  图片路径
     */
    imageBase64: function (url, cb) {
      bridge.call('Media', 'imageBase64', url, cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors  : chencm
   * @LastEditTime : 2020-01-03 18:04:51
   * @Description: 媒体 - 相机
   */

  var camera = {
    /**
     * @description 拍照
     * @type {Function}
     * @param {String} options
     * filename string 拍照或摄像文件保存的路径
     * format string	拍照或摄像的文件格式
     * index string	拍照或摄像头默认使用的摄像头	      Android-2.2+（不支持）
     * videoMaximumDuration string	视频长度	       Android-ALL（不支持）
     * optimize bool 是否优化图片	                    Ios-ALL（不支持
     * resolution bool 拍照或摄像分辨率	              Android-All（不支持）
     * popover bool 拍照或摄像界面弹出指示区域	        ios
     * @returns {String} payload : {capturedFile : ''}
     */
    captureImage: function (options, cb) {
      bridge.call('Media', 'captureImage', {
        "options": options
      }, cb);
    },

    /**
     * @description 获取摄像头管理对象
     * @type {Function}
     * @param {Object String} options  摄像头类型
     * {
     * "index":1,// 1:主摄像头  2:辅助摄像头
     * }
     * @returns [Array Object]
     * payload : {
     * supportedImageResolutions  字符串数组 摄像头支持的拍照分辨率
     * supportedVideoResolutions	字符串数组	摄像头支持的摄像分辨率
     * supportedImageFormats	    字符串数组	摄像头支持的拍照文件格式
     * supportedVideoFormats	    字符串数组	摄像头支持的摄像文件格式
     * }
     */
    getCamera: function (options, cb) {
      bridge.call('Media', 'getCamera', options, cb);
    },

    /**
    * @description 拍视频
    * @type {Function}
    * @param {Object} options
    * filename string 拍照或摄像文件保存的路径
    * format string	拍照或摄像的文件格式
    * index string	拍照或摄像头默认使用的摄像头	      Android-2.2+（不支持）
    * videoMaximumDuration string	视频长度	       Android-ALL（不支持）
    * @returns {String} payload : {capturedFile : '视频位置相对路径'}
    */
    startVideoCapture: function (options, cb) {
      bridge.call('Media', 'startVideoCapture', options, cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2020-01-02 11:29:39
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-02 17:13:58
   * @Description: 通讯录
   */

  var contacts = {
    /**
     * @param {Function} cb 回调
     * @returns payload
     * [{id,name,displayName,nickname,iphoneNum}]
     */
    getAddressBook: function (cb) {
      bridge.call('Contacts', 'getAddressBook', '', cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 11:25:42
   * @LastEditors  : helin3
   * @LastEditTime : 2019-12-30 21:11:09
   * @Description: Webview
   */

  /**
   * 转场类型
   */

  var AnimationType = {
    Fade: '1',
    // 淡入淡出
    Push: '2',
    // 推进效果
    Reveal: '3',
    // 揭开效果
    MoveIn: '4' // 慢慢进入并覆盖效果

  };
  var webview = {
    AnimationType: AnimationType,

    /**
     * 创建并显示 Webview
     * @param {Object} data {
     * url: (String)webview地址,
     * id_wvobj: (String)webviewid,
     * style: {width: (Number)宽度, height: (Number)高度}
     * @param {Function} cb 回调
     * }
     */
    open: function (data, cb) {
      bridge.call('Webview', 'create', data, function () {
        bridge.call('Webview', 'show', {
          id_wvobj: data.id_wvobj
        }, cb);
      });
    },

    /**
     * 创建 Webview
     * @param {Object} data {
     * url: (String)webview地址,
     * id_wvobj: (String)webviewid,
     * style: {width: (Number)宽度, height: (Number)高度}
     * @param {Function} cb 回调
     */
    create: function (data, cb) {
      bridge.call('Webview', 'create', data, cb);
    },

    /**
     * 显示 Webview
     * @param {String} id_wvobj id
     * @param {Function} cb 回调
     */
    show: function (wvid, cb) {
      bridge.call('Webview', 'show', {
        id_wvobj: wvid
      }, cb);
    },

    /**
     * push新的webview
     * @param {Object} data {url: String访问地址, animation: AnimationType转场类型}
     * @param {Function} cb 回调
     */
    pushNewWeb: function (data, cb) {
      bridge.call('Webview', 'pushNewWeb', data, cb);
    },

    /**
     * 关闭webview
     * @param {String} wvid webview id
     * @param {Function} cb 回调
     */
    close: function (wvid, cb) {
      bridge.call('Webview', 'close', {
        id_wvobj: wvid
      }, cb);
    },

    /**
     * 重新加载页面
     * @param {Function} cb 回调
     */
    reload: function (cb) {
      bridge.call('Webview', 'reload', {}, cb);
    },

    /**
    * 获取所有webviewid
    * @param {Function} cb 回调
    */
    all: function (cb) {
      bridge.call('Webview', 'all', {}, cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 21:57:03
   * @LastEditors  : helin3
   * @LastEditTime : 2020-02-13 10:55:54
   * @Description: 描述信息
   */

  var touchid = {
    /**
     * @description 验证指纹
     * @param {Function} cb 回调
     * @returns payload: {code: '', msg: ''}
     * 枚举值:
     * 0 指纹认证通过
     * 55001 指纹信息变更
     * 55002 设备不支持指纹识别
     * 55003 系统取消授权
     * 55004 用户取消验证Touch ID
     * 55005 授权失败
     * 55006 系统未设置密码
     * 55007 设备Touch ID不可用
     * 55008 TouchID未注册
     * 55009 用户选择输入密码
     * 55010 其他情况
     */
    fingerPrintVerification: function (cb) {
      bridge.call('TouchId', 'fingerPrintVerification', '', cb);
    },

    /**
     * @description 获取设备支持的生物识别类型
     * @param {Function} cb 回调
     * @returns payload: {biometricsType: '', biometricsText: ''}
     * biometricsType: 0 不支持touchid和faceid等生物识别；1 支持touchid；2 支持faceid
     */
    deviceBiometrics: function (cb) {
      bridge.call('TouchId', 'deviceBiometrics', '', cb);
    },

    /**
     * @description 是否支持指纹识别(已废弃)
     * @param {Function} cb
     * @returns {Boolean} hasFingerPrint {0:支持,1:不支持}
     */
    // hasFingerPrint: cb => {
    //   bridge.call('TouchId', 'hasFingerPrint', '', cb);
    // },

    /**
     * @description 更新变更后的指纹信息，前端其他安全方式验证后调用此方法
     * @param {Function} cb
     * @returns {Boolean} updateTouchIdResult
     */
    updateTouchId: function (cb) {
      bridge.call('TouchId', 'updateTouchId', '', cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 11:29:42
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-03 10:06:54
   * @Description: 二维码
   */

  var barcode = {
    /**
     * @param {Function} cb 回调
     * @returns
     * {String} status 错误码
     * {String} message 错误信息
     * {Object} payload 返回数据
     * {
     *  {String} codeResult: ''
     * }
     */
    scan: function (cb) {
      bridge.call('BarCode', 'scan', '', cb);
    },

    /**
     * 根据文字，生成二维码图片
     */
    createQRCodeImage: function (data, cb) {
      bridge.call('BarCode', 'createQRCodeImage', data, cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-28 09:34:27
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-16 16:51:29
   * @Description: 位置
   * TODO: 后续可考虑将位置信息缓存起来
   */
  // 监听事件ID

  var __WATCH_IDS__ = {};
  var location = {
    /**
     * 获取位置信息
     * @param {Function} cb 回调
     * @param {Object} option
     *   {String} enableHighAccuracy 是否高精确度获取位置信息默认是"1"，高精确度获取位置信息。字符串"0":不获取高精度。字符串"1":获取高精度值
     *   {Number} timeout 获取位置信息的超时时间,单位（秒）默认值30
     *   {Number} maximumAge 获取位置信息的间隔时间,单位（秒）默认30
     *   {String} coordsType 坐标系'GCJ-02（字段已废弃，默认返回GCJ-02）
     *   {String} geocode 是否解析地址信息 "1":返回地理位置信息+经纬度"0":只返回经纬度，默认"0"
     * @returns payload
     * coords
     *   {Long} longitude 经度
     *   {Long} latitude 维度
     * coordsType
     * address
     */
    getCurrentPosition: function (cb, option) {
      var data = {
        enableHighAccuracy: '1',
        timeout: 30,
        maximumAge: 30,
        // coordsType: 'GCJ-02',//'WGS-84',
        geocode: '0'
      };

      _extends(data, option);

      return bridge.call('Location', 'getCurrentPosition', data, cb);
    },

    /**
     * 监听设备位置变化信息
     * @param {Function} cb 回调
     * @param {Object} option
     *   {String} enableHighAccuracy 是否高精确度获取位置信息  默认是"1"，高精确度获取位置信息。字符串"0":不获取高精度。字符串"1":获取高精度值
     *   {Number} timeout 获取位置信息的超时时间,单位（秒）默认值30
     *   {Number} maximumAge 获取位置信息的间隔时间,单位（秒）默认30
     *   {String} coordsType 坐标系 GCJ-02（已废弃，直接返回GCJ-02坐标系）
     *   {String} geocode 是否解析地址信息"1":返回地理位置信息+经纬度 "0":只返回经纬度，默认"0"
     * @returns
     */
    watchPosition: function (cb, option) {
      var data = {
        enableHighAccuracy: "1",
        timeout: 30,
        maximumAge: 30,
        // coordsType: 'GCJ-02',//'WGS-84',
        geocode: "0"
      };

      _extends(data, option);

      var watchId = utils.uuid('timer');
      data.eventName = 'locationDidChanged';
      data.watchId = watchId;
      __WATCH_IDS__[watchId] = {
        cbid: bridge.call('Location', 'watchPosition', data, cb)
      };
      return watchId;
    },

    /**
     * 关闭指定监听设备位置信息
     * @param {string} watchId 需要取消的位置监听器标识，调用watchPosition方法的返回值
     * @param {Function} cb 回调
     * @return
     */
    clearWatch: function (watchId, cb) {
      if (!__WATCH_IDS__[watchId].cbid) {
        return;
      }

      var data = {
        watchId: watchId,
        callbackid: __WATCH_IDS__[watchId].cbid
      };
      bridge.call('Location', 'clearWatch', data, function (ret) {
        if (ret.status === utils.NATIVE_STATUS_CODE.OK) {
          // 移除原生事件监听对应的回调方法
          bridge.removeCb(__WATCH_IDS__[watchId].cbid);
        }

        cb(ret);
      });
    },

    /**
     * 关闭所有监听设备位置信息
     * @param {Function} cb 回调
     */
    clearWatchAll: function (cb) {
      bridge.call('Location', 'clearWatchAll', '', function (ret) {
        if (ret.status === utils.NATIVE_STATUS_CODE.OK) {
          Object.keys(__WATCH_IDS__).forEach(function (watchId) {
            // 移除原生事件监听对应的回调方法
            bridge.removeCb(__WATCH_IDS__[watchId].cbid);
            delete __WATCH_IDS__[watchId];
          });
        }

        cb(ret);
      });
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors  : chencm
   * @LastEditTime : 2020-01-14 21:49:25
   * @Description: 第三方服务 - 分享
   */

  var SHARE_CHANNALS = {
    'webchat': '1',
    'timeline': '2',
    'sina': '10',
    'dingtalk': '20'
  };
  var SHARE_TYPE = {
    'web': '0',
    'text': '1',
    'image': '2',
    'href': '3',
    'application': '4',
    'music': '5',
    'video': '6',
    'file': '7'
  };
  var share = {
    /**
     * @description 获取分享服务
     * @type {Function}
     * @param {String} options  使用sdk平台(目前只支持Mod)
     * @returns {Object Array}
     * channels:[{channel:'',name:''}]
     */
    getShareServices: function (options, cb) {
      bridge.call('Share', 'getShareServices', options, cb);
    },

    /**
     * @description 微信分享
     * @type {Function}
     * @param {Object String} options
     */
    sendByWechat: function (options, cb) {
      options = _extends(options, {
        channel: SHARE_CHANNALS[options.provider],
        type: SHARE_TYPE[options.type]
      });
      bridge.call('Share', 'sendWithSystem', options, cb);
    },

    /**
     * @description 朋友圈分享
     * @type {Function}
     * @param {Object String} options
     */
    sendByMoments: function (options, cb) {
      options = _extends(options, {
        channel: SHARE_CHANNALS[options.provider],
        type: SHARE_TYPE[options.type]
      });
      bridge.call('Share', 'sendWithSystem', options, cb);
    },

    /**
     * @description 新浪微博分享
     * @type {Function}
     * @param {Object String} options
     */
    sendBySina: function (options, cb) {
      options = _extends(options, {
        channel: SHARE_CHANNALS[options.provider],
        type: SHARE_TYPE[options.type]
      });
      bridge.call('Share', 'sendWithSystem', options, cb);
    },

    /**
     * @description 钉钉分享
     * @type {Function}
     * @param {Object String} options
     */
    sendByDingTalk: function (options, cb) {
      options = _extends(options, {
        channel: SHARE_CHANNALS[options.provider],
        type: SHARE_TYPE[options.type]
      });
      bridge.call('Share', 'sendWithSystem', options, cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors  : chencm
   * @LastEditTime : 2020-01-03 15:43:05
   * @Description: 第三方服务 - 推送
   */

  var push = {
    /**
     * @description 监听推送事件(已废弃)
     * @type {Function}
     * @param {String} options  事件参数
     * "click"  - 从系统消息中心点击消息启动应用事件
     * "receive"- 应用从推送服务器接收到推送消息事件
     */
    addEventListener: function (eventName, cb, isGlobel) {
      var options = {
        isGlobel: isGlobel || false,
        eventName: eventName
      };
      bridge.call('EventListener', 'addEventListener', options, cb);
    },

    /**
     * @description 清除通知中心的消息
     * @type {Function}
     */
    clear: function (cb) {
      bridge.call('Push', 'clear', '', cb);
    },

    /**
     * @description 创建本地消息
     * @type {Function}
     * @param {Object String} options
     * {
     *    content : String,
     *    payload : String,//消息承载的数据
     *    notificationId: String,//消息ID
     *    options : {
     *      cover : boolean,//默认false
     *      delay : long,//延迟显示秒数
     *      icon  : string,//消息图标
     *      sound : string,//推送消息音 默认 system
     *      title : string,//标题
     *      subtitle : string,//子标题
     *      when  : long //ios不支持，安卓支持显示推送时间
     *    }
     * }
     */
    createMessage: function (options, cb) {
      bridge.call('Push', 'createMessage', options, cb);
    },

    /**
     * @description 获取所有消息
     * @type {Function}
     * @returns [Array Object] 获取客户端接收到的所有本地消息
     */
    getAllMessage: function (cb) {
      bridge.call('Push', 'getAllMessage', {}, cb);
    },

    /**
     * @description 删除指定消息
     * @type {Function}
     * @param {String} msgId 消息ID
     */
    remove: function (msgId, cb) {
      bridge.call('Push', 'remove', msgId, cb);
    },

    /**
     * @description 获取客户端推送标识信息
     * @type {Function}
     * @returns {Object} payload:
     * {
     * clientInfo:
     *  {
     *    id String 推送通道标识
     *    token String 设备令牌（iOS设备唯一标识），用于APNS服务推送中标识设备的身份
     *    clientid String 设备唯一标识
     *    appid String 第三方推送服务的应用标识
     *    appkey String 第三方推送服务器的应用键值
     *   }
     * }
     */
    getClientInfo: function (cb) {
      bridge.call('Push', 'getClientInfo', '', cb);
    },

    /**
     * @description 设置程序是否将消息显示在系统消息中心
     * @type {Function}
     * @param {Object String} isNotify 是否通知
     */
    setAutoNotification: function (isNotify, cb) {
      bridge.call('Push', 'setAutoNotification', {
        "notify": isNotify
      }, cb);
    },

    /**
       * @description 设置推送tag
       * @type {Function}
       */
    setAlias: function (alias, cb) {
      bridge.call('Push', 'setAlias', alias, cb);
    },

    /**
     * @description 删除推送tag
     * @type {Function}
     */
    deleteAlias: function (cb) {
      bridge.call('Push', 'deleteAlias', {}, cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 21:23:01
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-03 16:14:37
   * @Description: OCR识别
   */

  var RecognizeType = {
    /**
     * 通用文字识别
     */
    Text: '0',

    /**
     * 身份证识别
     */
    IDCard: '1',

    /**
     * 身份证正面识别
     */
    IdCardFront: '2',

    /**
     * 身份证背面识别
     */
    IdCardBack: '3',

    /**
     * 银行卡识别
     */
    BankCard: '4',

    /**
     * 网络图片识别
     */
    WebImage: '5',

    /**
     * 驾驶证证识别
     */
    DrivingLicense: '6',

    /**
     * 行驶证识别
     */
    VehicleLicense: '7',

    /**
     * 车牌识别
     */
    PlateNumber: '8',

    /**
     * 营业执照识别
     */
    BusinessLicens: '9',

    /**
     * 票据识别
     */
    Receipt: '10',

    /**
     * iOCR识别
     */
    IOCRRecognition: '11'
  };
  var ocr = {
    /**
     * OCR识别类型
     */
    RecognizeType: RecognizeType,

    /**
     * @param {String} recognizeType OCR识别类型
     * @param {String} needBase64 "1"表示需要返回base64编码，其他不返回,默认0
     * @param {Function} cb 回调
     * @returns
     * {Object} payload
     */
    startOCR: function (recognizeType, cb, needBase64) {
      if (needBase64 === void 0) needBase64 = '0';
      bridge.call('OCR', 'startOCR', {
        recognizeType: recognizeType,
        needBase64: needBase64
      }, cb);
    },

    /**
     * 获取OCR支持的服务
     * @param {Object} sdkType 默认值: Baidu
     * @param {Function} cb 回调
     * @returns {Object} retObject
     * {String} status 错误码
     * {String} message 错误信息
     * {Object} payload 返回数据 {
     *  ocrSupports: [
     *  0-'通用文字识别',
     *  1-'身份证识别',
     *  2-'身份证正面识别',
     *  3-'身份证背面识别',
     *  4-'银行卡识别',
     *  5-'网络图片识别',
     *  6-'驾驶证证识别',
     *  7-'行驶证识别',
     *  8-'车牌识别',
     *  9-'营业执照识别',
     *  10-'票据识别',
     *  11-'iOCR识别'
     * ]
     * }
     */
    getOCRServices: function (sdkType, cb) {
      sdkType = sdkType || 'Baidu';
      bridge.call('OCR', 'getOCRServices', {
        sdkType: sdkType
      }, cb);
    }
  };
  /**
   * @created by helin3 2019-12-30
   * @updated by
   * @description Face 人脸识别/活体检测
   */

  var face = {
    /**
     * 人脸识别/活体检测
     * @param {Object} data 请求参数
     * {
     *   {String} livenessType ['meglive': 动作活体; 'still': 静默活体; 'flash': 炫彩活体]
     *   {String} username 姓名
     *   {String} idcard 身份证号
     * }
     * @param {Function} cb 回调
     * @returns
     */
    face: function (data, cb) {
      bridge.call('Face', 'face', data, cb);
    },

    /**
     * 二代证识别
     * @param {Object} data
     * *{String} ScreenOrientation 0：竖屏 1：横屏
     * *{String} IDCardShootPage 0：身份证人像；1：国徽面
     * @param {Function} cb 回调
     * @returns
     */
    idcard: function (data, cb) {
      bridge.call('Face', 'idcard', data, cb);
    }
  };
  /*
   * @Author: chencm
   * @Date: 2020-01-06 14:19:20
   * @LastEditors  : chencm
   * @LastEditTime : 2020-01-10 16:37:49
   * @Description: 客户端事件
   */

  var KeyEvent = {
    'background': [],
    // 切换到后台
    'foreground': [],
    // 切换到前台
    'backbutton': [],
    // 物理键返回
    'netchange': [],
    // 网络状态变化
    'locationDidChanged': [],
    //位置信息变化监听
    'pushMessage': [],
    // 收到推送
    'KeyboardHeightChange': [] //系统键盘高度变化

  };
  var events = {
    /**
     * @description 绑定监听事件
     * @type {Function}
     * @param {String} eventName  事件名
     * @param {Function} cb  回调函数
     * @param {String} global 全局标识 0/true:为全局监听即所有webview都监听，1/false/默认:为当前webview监听
     */
    addEventListener: function (eventName, cb, global) {
      if (global === void 0) global = '1';

      if (!eventName || !cb) {
        return;
      }

      if (typeof global === 'boolean') {
        global = global ? '0' : '1';
      }

      var callbackid = bridge.call('EventListener', 'addEventListener', {
        eventName: eventName,
        isGlobel: global
      }, cb);
      var fnObj = {
        'callbackid': callbackid,
        'fn': cb
      };
      global == '1' && KeyEvent[eventName] && KeyEvent[eventName].push(fnObj);
    },

    /**
     * @description 移除监听事件
     * @type {Function}
     * @param {String} eventName  事件名
     * @param {Function} cb  回调函数
     * @param {String} global 全局标识 0:为全局监听即所有webview都监听，1:为当前webview监听
     */
    removeEventListener: function (eventName, cb, global) {
      if (global === void 0) global = '1';

      if (!eventName || !cb) {
        return;
      }

      var eventArray = KeyEvent[eventName];

      if (eventArray) {
        // 目前不支持批量移除事件
        var index = eventArray.findIndex(function (obj) {
          return toString(obj.fn) === toString(cb);
        });

        if (~index) {
          var target = eventArray.splice(index, 1);
          bridge.call('EventListener', 'removeEventListener', {
            'callbackid': global === 0 ? globalCbId[eventName] : target[0]['callbackid']
          }, cb);
        }
      }
    }
  };
  /*
   * @Author: chencm
   * @Date: 2019-12-30 10:14:00
   * @LastEditors  : chencm
   * @LastEditTime : 2019-12-31 21:16:19
   * @Description: 设备信息
   */

  var nativeUI = {
    /**
     * @description 选择框actionsheet
     * @type {Function}
     * @param {String} data {"title":"这是一条actionSheet","cancel":"取消","buttons":["sheet1","sheet2","sheet3"]}
     * @returns {Number,String}  payload : {index : Number,content : String}
     */
    actionsheet: function (data, cb) {
      bridge.call('ActionSheet', 'actionSheet', data, cb);
    },

    /**
     * @description 显示等待进度条
     * @type {Function}
     * @param {String} msg 进度条显示文字描述
     * @returns
     */
    showWaiting: function (msg, cb) {
      bridge.call('Loading', 'showWaiting', msg, cb);
    },

    /**
     * @description 关闭进度条
     * @type {Function}
     * @param {String}
     */
    closeWaiting: function (cb) {
      bridge.call('Loading', 'closeWaiting', '', cb);
    },

    /**
     * @description 面包屑
     * @type {Function}
     * @param {String} msg 显示内容
     */
    toast: function (msg, cb) {
      bridge.call('Toast', 'toast', msg, cb);
    }
  };
  /*
   * @Author: helin3
   * @Date: 2019-12-30 11:29:42
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-03 10:06:54
   * @Description: 二维码
   */

  var voice = {
    /**
     * @param {Function} cb 回调
     * @returns
     * {String} status 错误码
     * {String} message 错误信息
     * {Object} payload 返回数据
     * {
     *  {String} codeResult: ''
     * }
     */
    speaking: function (data, cb) {
      bridge.call('Voice', 'speaking', data, cb);
    }
  };
  /*
   * @Author: tuyc3
   * @Date: 2019-12-30 11:29:42
   * @LastEditors  : helin3
   * @LastEditTime : 2020-01-03 10:06:54
   * @Description: 用呗
   */

  var madcore = {
    /**
     * @param {Function} cb 回调
     * @returns
     * {String} status 错误码
     * {String} message 错误信息
     * {Object} payload 返回数据
     * {
     *  {String} codeResult: ''
     * }
     */
    jumpMadCore: function (data, cb) {
      bridge.call('madcore', 'jumpMadCore', data, cb);
    }
  };
  /**
   * @created by zhengchao
   * @updated by
   * @description gestrue 说是解锁
   */

  var gesture = {
    /**
     * 手势解锁
     *
     * {"unlockType":"1","userIdentify":"1234","maxErrorTimes":"5","gesturePswd":"xxxxx"};
     *
     */
    openUnlock: function (data, cb) {
      bridge.call('Gesture', 'openUnlock', data, cb);
    },

    /**
     * 删除当前用户手势信息
     *
     * {"unlockType":"1","userIdentify":"1234","maxErrorTimes":"5","gesturePswd":"xxxxx"};
     *
     */
    clearGestureInfo: function (data, cb) {
      bridge.call('Gesture', 'clearGestureInfo', data, cb);
    },

    /**
     * 获取当前用户手势数据
     *
     * {"unlockType":"1","userIdentify":"1234","maxErrorTimes":"5","gesturePswd":"xxxxx"};
     *
     */
    currentGesture: function (data, cb) {
      bridge.call('Gesture', 'currentGesture', data, cb);
    },

    /**
     * 删除错误试错数据
     *
     * {"unlockType":"1","userIdentify":"1234","maxErrorTimes":"5","gesturePswd":"xxxxx"};
     *
     */
    clearGestureErrorTimes: function (data, cb) {
      bridge.call('Gesture', 'clearGestureErrorTimes', data, cb);
    }
  };
  /*
   * @Author: zhoubingyu
   * @Date: 2020-05-20 17:29:42
   * @LastEditors  : zhoubingyu
   * @LastEditTime : 2020-05-20 17:06:54
   * @Description: 加密解密
   */

  var encryptDescrypt = {
    /**
     * @param {Function} cb 回调
     * @returns
     * {String} status 错误码
     * {String} message 错误信息
     * {Object} payload 返回数据
     * {
     *  {String} codeResult: ''
     * }
     */
    aes: function (data, cb) {
      bridge.call('EncryptDesEncrypt', 'aseAction', data, cb);
    }
  };

  /*
   * @Author: zhaoyanhu
   * @Date: 2021-01-18
   * @Description: 在线客服
   */
  var customer = {
    /**
     * @param {Function} cb 回调
     * @param {Object} 参数
     * @returns
     * {String} status 成功/失败
     * }
     */
    manualService: function (data, cb) {
          bridge.call('customer', 'manualService', data, cb);
    }
  }
  /*
   * @Author: helin3
   * @Date: 2019-12-30 21:18:23
   * @LastEditors  : helin3
   * @Description: 导出native方法
   */

  var logger$5 = utils.logger;
  var sdk = {
    call: bridge.call,
    logger: logger$5,
    http: http,
    downloader: downloader,
    uploader: uploader,
    device: device,
    networkinfo: networkinfo,
    screen: screen,
    storage: storage,
    clipboard: clipboard,
    runtime: runtime,
    io: io,
    zip: zip,
    key: key,
    pwdkey: pwdkey,
    gallery: gallery,
    camera: camera,
    contacts: contacts,
    webview: webview,
    touchid: touchid,
    voice: voice,
    madcore: madcore,
    barcode: barcode,
    location: location,
    share: share,
    push: push,
    ocr: ocr,
    face: face,
    events: events,
    nativeUI: nativeUI,
    gesture: gesture,
    encryptDescrypt: encryptDescrypt,
    customer: customer
  };
  window.__FOX_NATIVE_EVAL__ = bridge.nativeEval; // 开发调式模式将foxsdk绑定到window上，供app-fox和uni-stat使用原生全局对象
  // trycatch是为避免浏览器环境报错

  try {
    process.env.NODE_ENV === 'development' ? window.foxsdk = sdk : void 0;
  } catch (e) {}

  return sdk;
});
